recurrence library
Classes
-
Alignable<
T extends RecurrenceRule> - IntervalRecurrenceRule
- This rule does not consider any type of special logic, such as leap years, clamping, or overflow.
- MonthlyRecurrenceRule
- A specific day of the month.
- Recurrence
- Use this class to define a recurrence pattern.
-
RecurrenceRule<
T> - RecurrenceRule does not represent any occurrence, or point in time. It simply represents how one should calculate the next occurence based off of an anchor (from).
- WeeklyRecurrenceRule
- Each week's same weekday.
- YearlyRecurrenceMonthDay
- Each year's same day and month.
- YearlyRecurrenceRule